@@ -18,7 +18,7 @@ package Dist::Zilla::Plugin::GitVersionCheckCJM;
 #---------------------------------------------------------------------
 
 our $VERSION = '3.02';
-# This file is part of Dist-Zilla-Plugins-CJM 3.02 (November 11, 2010)
+# This file is part of Dist-Zilla-Plugins-CJM 3.03 (December 7, 2010)
 
 
 use version 0.77 ();
@@ -159,8 +159,8 @@ Dist::Zilla::Plugin::GitVersionCheckCJM - Ensure version numbers are up-to-date
 =head1 VERSION
 
 This document describes version 3.02 of
-Dist::Zilla::Plugin::GitVersionCheckCJM, released November 11, 2010
-as part of Dist-Zilla-Plugins-CJM version 3.02.
+Dist::Zilla::Plugin::GitVersionCheckCJM, released December 7, 2010
+as part of Dist-Zilla-Plugins-CJM version 3.03.
 
 =head1 SYNOPSIS
 
@@ -234,7 +234,7 @@ or through the web interface at
 L<http://rt.cpan.org/Public/Bug/Report.html?Queue=Dist-Zilla-Plugins-CJM>
 
 You can follow or contribute to Dist-Zilla-Plugins-CJM's development at
-git://github.com/madsen/dist-zilla-plugins-cjm.git.
+L<< http://github.com/madsen/dist-zilla-plugins-cjm >>.
 
 =head1 COPYRIGHT AND LICENSE
 
