@@ -18,7 +18,7 @@ package Dist::Zilla::Plugin::VersionFromModule;
 #---------------------------------------------------------------------
 
 our $VERSION = '0.08';
-# This file is part of Dist-Zilla-Plugins-CJM 3.02 (November 11, 2010)
+# This file is part of Dist-Zilla-Plugins-CJM 3.03 (December 7, 2010)
 
 use Moose;
 with 'Dist::Zilla::Role::VersionProvider';
@@ -57,8 +57,8 @@ Dist::Zilla::Plugin::VersionFromModule - Get distribution version from its main_
 =head1 VERSION
 
 This document describes version 0.08 of
-Dist::Zilla::Plugin::VersionFromModule, released November 11, 2010
-as part of Dist-Zilla-Plugins-CJM version 3.02.
+Dist::Zilla::Plugin::VersionFromModule, released December 7, 2010
+as part of Dist-Zilla-Plugins-CJM version 3.03.
 
 =head1 SYNOPSIS
 
@@ -95,7 +95,7 @@ or through the web interface at
 L<http://rt.cpan.org/Public/Bug/Report.html?Queue=Dist-Zilla-Plugins-CJM>
 
 You can follow or contribute to Dist-Zilla-Plugins-CJM's development at
-git://github.com/madsen/dist-zilla-plugins-cjm.git.
+L<< http://github.com/madsen/dist-zilla-plugins-cjm >>.
 
 =head1 COPYRIGHT AND LICENSE
 
